@@ -1,7 +1,7 @@
 "robustd.t" <- function(X, dfreq=FALSE, vt, vm="M0", vh=list("Chao"), vtheta=2, neg=TRUE)
 {
 ########################################################################################
-# Validation des arguments fournis en entre et changement de leur forme si ncessaire
+# Validation des arguments fournis en entree et changement de leur forme si necessaire
 ########################################################################################
 
         valid.one(dfreq,"logical")
@@ -15,11 +15,11 @@
         valid.one(neg,"logical")
     
 ##########################################################################################
-# AJUSTEMENT DU MODLE
+# AJUSTEMENT DU MODeLE
 ##########################################################################################
 
 #-------------------------------------#
-# laboration et ajustement du modle #
+# elaboration et ajustement du modele #
 #-------------------------------------#
 
         Y <- histfreq.t(X,dfreq=dfreq)
@@ -39,22 +39,22 @@
         colnames(mX.) <- c(gammanames,Xw$coeffnames)
         dimX <- dim(mX.)[2]
 
-        # Ajustement du modle
+        # Ajustement du modele
         anaMrd <- suppressWarnings(glm(Y~mX.,family=poisson))
 
-    #Vrification du bon ajustement du modle loglinaire
+    #Verification du bon ajustement du modele loglineaire
     if(!anaMrd$converged) stop("'glm' did not converge")
     if(any(is.na(anaMrd$coef))) warning("some loglinear parameter estimations cannot be evaluated")
 
 #-----------------------------------------------------------------------------------#
-# Rajustement du modle en enlevant les gamma et les eta (si modle Chao) ngatifs #
+# Reajustement du modele en enlevant les gamma et les eta (si modele Chao) negatifs #
 #-----------------------------------------------------------------------------------#
 
         param<-anaMrd$coef
         ppositions <- 0
         if (neg)
         {
-            # Vecteur d'indicatrices pour les paramtres d'intrt ngatifs
+            # Vecteur d'indicatrices pour les parametres d'interet negatifs
             indic <- as.vector(c(0,ifelse(param[2:(2*I-1)]<0,1,0)))
             for (i in 1:I)
             {
@@ -65,20 +65,20 @@
                     indic <- as.vector(c(indic,rep(0,Xw$nbcoeff[i])))
                 }
             }
-            while(sum(na.rm=TRUE,indic)>0) # Rpter la boucle jusqu' ce qu'aucun gamma appropri ne soit ngatif
+            while(sum(na.rm=TRUE,indic)>0) # Repeter la boucle jusqu'a ce qu'aucun gamma approprie ne soit negatif
             {
-                # Dtermination de la position du premier gamma appropri ngatif
+                # Determination de la position du premier gamma approprie negatif
                 pos <- 1
                 while(indic[pos]==0) pos <- pos + 1
                 ppositions <- c(ppositions,pos)
-                # Retrait de la bonne colonne de mX. et rajustement du modle
+                # Retrait de la bonne colonne de mX. et reajustement du modele
                 mX. <- mX.[,-(pos-sum(na.rm=TRUE,ppositions<pos))]
                 anaMrd <- suppressWarnings(glm(Y~mX.,family=poisson))
-                # Ajout de zros dans le vecteur des paramtres loglinaires
+                # Ajout de zeros dans le vecteur des parametres loglineaires
                 positions <- sort(ppositions[-1])                
                 param <- rep(0,dimX+1)
                 param[-positions] <- anaMrd$coef 
-                # Vecteur d'indicatrices pour les paramtres d'intrt ngatifs
+                # Vecteur d'indicatrices pour les parametres d'interet negatifs
                 indic <- as.vector(c(0,ifelse(param[2:(2*I-1)]<0,1,0)))
                 for (i in 1:I)
                 {
@@ -94,7 +94,7 @@
         positions <- sort(ppositions[-1]) 
 
 #------------------------------------------------------------------------#
-# Ajustement d'un modle pour tester la prsence d'migration temporaire #
+# Ajustement d'un modele pour tester la presence d'emigration temporaire #
 #------------------------------------------------------------------------#
 
         Inono <- length(vm[vm!="none"])
@@ -126,7 +126,7 @@
         }
      
 #---------------------------------------#
-# Formation des vecteurs des paramtres #
+# Formation des vecteurs des parametres #
 #---------------------------------------#
 
         # valeur de l intercept
@@ -147,7 +147,7 @@
         }
 
 
-        # Vrification de la prsence de paramtres gamma ngatifs si l'option "neg"=FALSE
+        # Verification de la presence de parametres gamma negatifs si l'option "neg"=FALSE
         if(!neg)
         {
             if (any(Alpha<0)) warning("one or more gamma parameters are negative,\n",
@@ -155,7 +155,7 @@
         }
 
 #--------------------------------------------------------------#
-# Matrice de variances-covariances des paramtres loglinaires #
+# Matrice de variances-covariances des parametres loglineaires #
 #--------------------------------------------------------------#
 
         if(length(positions)>0) {
@@ -164,7 +164,7 @@
         } else varcov <- summary(anaMrd)$cov.unscaled  
 
 ########################################################################################
-# Estimation des paramtres dmographiques
+# Estimation des parametres demographiques
 ########################################################################################
 
 #--------------------------------------------#
@@ -186,7 +186,7 @@
                         pstar[i] <- 1-prod((1+exp(beta[c(1:vt[i])]))^-1)
                         dpstar[(2*I + if(i>1) sum(na.rm=TRUE,Xw$nbcoeff[1:(i-1)]) else 0):(2*I-1+sum(na.rm=TRUE,Xw$nbcoeff[1:i])),i] <- prod((1+exp(beta[c(1:vt[i])]))^-1)*exp(beta[c(1:vt[i])])/(1+exp(beta[c(1:vt[i])]))
                         beta <- beta[-c(1:vt[i])]
-                } else # Tous les autres modles
+                } else # Tous les autres modeles
                 {
                         Xpf <- Xclosedp(vt[i],vm[i],vh[[i]],vtheta[i])
                         pstar[i] <- sum(na.rm=TRUE,exp(Xpf$mat%*%beta[c(1:Xpf$nbcoeff)]))/(1+ sum(na.rm=TRUE,exp(Xpf$mat%*%beta[c(1:Xpf$nbcoeff)])))
@@ -303,7 +303,7 @@
         BStderr <- sqrt(diag(varcovB))
           
 #--------------------------------------------------------------------#
-# Calcul du nombre total d'individus qui ont pass sur le territoire #
+# Calcul du nombre total d'individus qui ont passe sur le territoire #
 #--------------------------------------------------------------------#
 
         Ntot <- Npop[1]+sum(na.rm=TRUE,B)
@@ -311,7 +311,7 @@
         NtotStderr <- sqrt(max(t(dNtot)%*%varcov%*%dNtot-Ntot,0))
 
 #######################################################################################
-# Prsentation des rsultats
+# Presentation des resultats
 #######################################################################################
 
         modelfit <- matrix(c(anaMrd$deviance,anaMrd$df.residual,anaMrd$aic),nrow=1)
@@ -354,7 +354,7 @@
         models<-matrix(Xw$models,nrow=1)
         dimnames(models) <- list("model",titre.periode)
 
-        # Matrice de variances-covariances des paramters pstar, phi, Npop, B et Ntot
+        # Matrice de variances-covariances des parameters pstar, phi, Npop, B et Ntot
         dP <- cbind(dpstar,dphi,dNpop,dB,dNtot)
         covP <- t(dP)%*%varcov%*%dP
         titre.P <- c(rep(0,4*I-2),"Ntot")
@@ -411,8 +411,8 @@ print.robustd <- function(x, ...){
         print.default(x$Ntot, print.gap = 2, quote = FALSE, right=TRUE, na.print="--", ...)
         cat("\nTotal number of captured units:",x$n,"\n")
         ###################################################
-        ### 22 mai 2012 : On a dcid de ne plus imprimer ces notes car l'utilisateur ne comprend pas quel
-        ### impact des parametres eta fixs  zro ont sur ses rsultats. a l'embte plus qu'autre chose.
+        ### 22 mai 2012 : On a decide de ne plus imprimer ces notes car l'utilisateur ne comprend pas quel
+        ### impact des parametres eta fixes a zero ont sur ses resultats. ca l'embete plus qu'autre chose.
         #if (length(x$neg[x$neg<2*dim(x$N)[1]])==1) cat("\nNote:",length(x$neg[x$neg<2*dim(x$N)[1]]),"gamma parameter has been set to zero\n")
         #if (length(x$neg[x$neg<2*dim(x$N)[1]])>1) cat("\nNote:",length(x$neg[x$neg<2*dim(x$N)[1]]),"gamma parameters have been set to zero\n")
         #if (length(x$neg[x$neg>=2*dim(x$N)[1]])==1) cat("\nNote:",length(x$neg[x$neg>=2*dim(x$N)[1]]),"eta parameter has been set to zero\n")
